@@ -1,4 +1,3 @@
-
 class RectangleBoxObjectDetectionResponse:
     _response_type = "rectangle_box_detection"
 
@@ -18,27 +17,43 @@ class RectangleBoxObjectDetectionResponse:
             "ymax": int(ymax)
         })
 
-    def dumps(self):
+    def dumps(self, error=""):
         return {
             "type": type(self)._response_type,
             "height": self.height,
             "width": self.width,
             "depth": self.depth,
-            "objects": self.objects
+            "objects": self.objects,
+            "error": error,
         }
 
 
 class ClassificationResponse:
     _response_type = "classification"
 
-    def __init__(self, class_id, class_name=None):
-        self.class_id = class_id
-        self.class_name = class_name
-
-    def dumps(self):
+    @staticmethod
+    def dumps(height, width, depth, class_id, class_name=None, error=""):
         return {
-            "type": type(self)._response_type,
-            "class_id": self.class_id,
-            "class_name": self.class_name,
+            "type": ClassificationResponse._response_type,
+            "height": height,
+            "width": width,
+            "depth": depth,
+            "class_id": class_id,
+            "class_name": class_name,
+            "error": error,
         }
 
+
+class SegmentationResponse:
+    _response_type = "segmentation"
+
+    @staticmethod
+    def dumps(height, width, depth, mask, error=""):
+        return {
+            "type": SegmentationResponse._response_type,
+            "height": height,
+            "width": width,
+            "depth": depth,
+            "mask": mask,
+            "error": error,
+        }
